==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Tdo-los temas");
define("_NOCOMMENTS","Sen comentarios");
define("_UCOMMENT","Comentario");
define("_REVIEWS","Reseas");
define("_SEARCHUSERS","Buscar nos Usuarios");
define("_SEARCHSECTIONS","Buscar nas Seccins Especiales");
define("_SEARCHREVIEWS","Buscar nas Reseas");
define("_SEARCHIN","Buscar en");
define("_ARTICLES","Artigos");
define("_ALLAUTHORS","Tdo-los Autores");
define("_ALL","Todo");
define("_WEEK","Semana");
define("_WEEKS","Semanas");
define("_MONTH","Mes");
define("_MONTHS","Meses");
define("_SEARCHON","Buscar en");
define("_SSTORIES","Noticias");
define("_SSECTIONS","Seccins");
define("_SUSERS","Usuarios");
define("_NOMATCHES","Non hai rexistros para a sa consulta");
define("_PREVMATCHES","Rexistros anteriores");
define("_NEXTMATCHES","Rexistros seguintes");
define("_INSECTION","na Seccin");
define("_NONAME","Non introduciu un nome");
define("_SCOMMENTS","Comentarios");
define("_SEARCHRESULTS","Resultados da Bsqueda");
define("_CONTRIBUTEDBY","Contribucin de");
define("_UCOMMENTS","Comentarios");
define("_MATCHTITLE","Buscar por ttulo");
define("_MATCHTEXT","Buscar por contido");
define("_MATCHBOTH","Buscar por ambos");
define("_SREPLY","respostan");
define("_SREPLIES","resposta");
define("_ATTACHART","Adxuntar  artigo");
define("_PAGES","Pxinas");
define("_REVIEWSCORE","Valoracin para esta resea");
define("_PAGE","pxina(s) ");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Tdo-los temas");
define("_NOCOMMENTS","Sen comentarios");
define("_UCOMMENT","Comentario");
define("_REVIEWS","Reseas");
define("_SEARCHUSERS","Buscar nos Usuarios");
define("_SEARCHSECTIONS","Buscar nas Seccins Especiales");
define("_SEARCHREVIEWS","Buscar nas Reseas");
define("_SEARCHIN","Buscar en");
define("_ARTICLES","Artigos");
define("_ALLAUTHORS","Tdo-los Autores");
define("_ALL","Todo");
define("_WEEK","Semana");
define("_WEEKS","Semanas");
define("_MONTH","Mes");
define("_MONTHS","Meses");
define("_SEARCHON","Buscar en");
define("_SSTORIES","Noticias");
define("_SSECTIONS","Seccins");
define("_SUSERS","Usuarios");
define("_NOMATCHES","Non hai rexistros para a sa consulta");
define("_PREVMATCHES","Rexistros anteriores");
define("_NEXTMATCHES","Rexistros seguintes");
define("_INSECTION","na Seccin");
define("_NONAME","Non introduciu un nome");
define("_SCOMMENTS","Comentarios");
define("_SEARCHRESULTS","Resultados da Bsqueda");
define("_CONTRIBUTEDBY","Contribucin de");
define("_UCOMMENTS","Comentarios");
define("_MATCHTITLE","Buscar por ttulo");
define("_MATCHTEXT","Buscar por contido");
define("_MATCHBOTH","Buscar por ambos");
define("_SREPLY","respostan");
define("_SREPLIES","resposta");
define("_ATTACHART","Adxuntar  artigo");
define("_PAGES","Pxinas");
define("_REVIEWSCORE","Valoracin para esta resea");
define("_PAGE","pxina(s) ");

?>
